Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0022-46 Inscrição Estadual: 1090357130
RS 509 KM 07, 5941, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 36401 Série: 213 Data de Emissão: 27/11/2019 13:56:26
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1187 3978 6500 2246 6521 3000 0364 0110 0396 3703
Protocolo de Autorização: 143191639099881
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
10067230 | M TOMATE FUGINI TRAD ZERO SC 340G | 5 | UN | 1,99 | 9,95
362480020 | MASSA INTEGRAL ORQUIDEA 500G. PENNE | 1 | UN | 3,49 | 3,49
629890 | MASSA ARROZ INTEGRAL URBANO PARAFUS 500G | 1 | UN | 4,89 | 4,89
484700 | ERVA MATE REI VERDE NATURAL 1KG | 1 | UN | 10,48 | 10,48
5520 | FRUTI - LIMAO TAITI KG | 0,545 | KG | 7,89 | 4,30
2040 | FRUTI - BANANA PRATA KG | 1,67 | KG | 4,99 | 8,33
434590 | PADARIA - PAO FRANCES PERUZZO KG | 0,514 | KG | 7,69 | 3,95
5130 | HORTI - CEBOLA NACIONAL KG | 0,5 | KG | 2,49 | 1,24
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 4,59 | 4,59
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 4,59 | 4,59
633550 | CASTANHA CAJU INT LA VIOLETERA SC 100G | 1 | UN | 15,9 | 15,90
Valor total R$ | 71,71
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:36